@@ -76,6 +76,7 @@ bool test01() {
   test &= state1 == state2;
   test &= !static_cast<bool>(state2 & statefail);
 
+
   // template<_CharT, _Traits>
   //  basic_istream& operator>>(istream&, unsigned char*)
   unsigned char array2[n];
@@ -90,6 +91,7 @@ bool test01() {
   int1 = is_02.peek(); // should be ' '
   test &= int1 == ' ';
 
+
    // template<_CharT, _Traits>
   //  basic_istream& operator>>(istream&, signed char*)
   signed char array3[n];
@@ -103,6 +105,48 @@ bool test01() {
   int1 = is_02.peek(); // should be ' '
   test &= int1 == ' ';
  
+
+  // testing with width() control enabled.
+  is_02.width(8);
+  state1 = is_02.rdstate();
+  is_02 >> array1;   // should snake a
+  state2 = is_02.rdstate();
+  test &= state1 == state2;
+  test &= !ctraits_type::compare(array1, "a", 2);
+
+  is_02.width(1);
+  state1 = is_02.rdstate();
+  is_02 >> array1;   // should snake nothing, set failbit
+  state2 = is_02.rdstate();
+  test &= state1 != state2;
+  test &= state2 == statefail;
+  test &= array1[0] == '\0';
+
+  is_02.width(8);
+  is_02.clear();
+  state1 = is_02.rdstate();
+  test &= !state1;
+  is_02 >> array1;   // should snake "morning"
+  state2 = is_02.rdstate();
+  test &= state1 == state2;
+  test &= !ctraits_type::compare(array1, "morning", 8);
+
+  // testing for correct exception setting
+  const std::string str_04("   impulse!!");
+  std::stringbuf isbuf_03(str_04, std::ios_base::in);
+  std::stringbuf isbuf_04(str_04, std::ios_base::in);
+  std::istream is_03(&isbuf_03);
+  std::istream is_04(&isbuf_04);
+
+  is_03 >> array1;
+  test &=  !ctraits_type::compare(array1,"impulse!!", 10);
+  test &= is_03.rdstate() == std::ios_base::eofbit;
+
+  is_04.width(9);
+  is_04 >> array1;
+  test &=  ! std::ios::traits_type::compare(array1,"impulse!", 9);
+  test &= !is_04.rdstate(); 
+
 #ifdef DEBUG_ASSERT
   assert(test);
 #endif
